pub enum OwnedStorage<const N: usize> {}Expand description
Implementation of Storage that stores the data in an array [T; N] whose size is known at
compile time.
pub enum OwnedStorage<const N: usize> {}Implementation of Storage that stores the data in an array [T; N] whose size is known at
compile time.